Crate minigreprfoxkendo

Crate minigreprfoxkendo 

minigreprfoxkendo crate

This crate contains utility functions for the minigrep example program

Structs

Arguments
Contains the results of program parameter parsing. The pattern field is the pattern searched for in the data filename field is the path to the file that will be grepped.

Functions

open_file
Open the input file.
process_args
Process the command line arguments for minigreprfoxkendo.